<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>



-------------------------------------------------------------------------------

## 📚简介

popdf 是python自动化办公之Excel操作的第三方库。

来自于开源项目：python-office，[📘官网：https://www.python-office.com/](https://www.python-office.com/)。

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ popdf -U
```

-------------------------------------------------------------------------------

## 📝功能

已有功能的说明如下：

| 序号 | 方法名        | 功能         | 视频                                                                    | 文档                                                                                                                                        | 演示代码                                                                                                       |
| ---- | ------------- | ------------ | ----------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------- |
| 1    | add_watermark | PDF加水印    | [播放](https://www.bilibili.com/video/BV1Se411T7au)                     | [查看](https://mp.weixin.qq.com/s?__biz=MzI2Nzg5MjgyNg==&mid=2247496501&idx=1&sn=1c2c8f2590ea355f82e24336a0a0aae0&scene=21#wechat_redirect) | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/popdf/PDF%E5%8A%A0%E6%B0%B4%E5%8D%B0.py) |
| 2    | txt2pdf       | TXT转PDF     | [文档](https://blog.csdn.net/weixin_42321517/article/details/130612189) | [查看](https://mp.weixin.qq.com/s?__biz=MzI2Nzg5MjgyNg==&mid=2247496561&idx=1&sn=843d9c491177d9558c11897ca7c4c221&scene=21#wechat_redirect) | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/popdf/TXT%E8%BD%ACPDF.py)                |
| 3    | encrypt4pdf   | PDF加密      | [文档](https://blog.csdn.net/weixin_42321517/article/details/129963432) | [查看](https://mp.weixin.qq.com/s?__biz=MzI2Nzg5MjgyNg==&mid=2247496561&idx=1&sn=843d9c491177d9558c11897ca7c4c221&scene=21#wechat_redirect) | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/popdf/PDF%E5%8A%A0%E5%AF%86.py)          |
| 4    | decrypt4pdf   | PDF解密      | [文档](https://mp.weixin.qq.com/s/GiXYB_xZdlsYv5AIeIELkA)               | [查看](https://mp.weixin.qq.com/s?__biz=MzI2Nzg5MjgyNg==&mid=2247496561&idx=1&sn=843d9c491177d9558c11897ca7c4c221&scene=21#wechat_redirect) | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/popdf/PDF%E8%A7%A3%E5%AF%86.py)          |
| 5    | merge2pdf     | 合并PDF      | [文档](https://baijiahao.baidu.com/s?id=1733062611567959337)            | [查看](https://mp.weixin.qq.com/s?__biz=MzI2Nzg5MjgyNg==&mid=2247496589&idx=2&sn=2519406d2afc795e7a2f346659f87cb7&scene=21#wechat_redirect) | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/popdf/%E5%90%88%E5%B9%B6PDF.py)          |
| 6    | pdf2docx      | 💻PDF 转 Word | 💻 [播放](https://www.bilibili.com/video/BV19D4y1i7Eu)                   | [查看](https://mp.weixin.qq.com/s?__biz=MzUzNTc5NjA4NQ==&mid=2247493574&idx=1&sn=8d7b6dbe12330e67a3dd06085aa65cac&scene=21#wechat_redirect) | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/popdf/pdf%E8%BD%ACword.py)               |
| 7    | pdf2imgs      | PDF 转 图片  | 💻[文档](https://mp.weixin.qq.com/s/Ve5FH6q6ZqNbhUUG9RR8aw)              | [查看](https://mp.weixin.qq.com/s/s3oi0jNOpolT7lLQEjCNTw)                                                                                   | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/popdf/pdf%E8%BD%AC%E5%9B%BE%E7%89%87.py) |

## 🏗️添砖加瓦

本项目欢迎任何人参与开发，如果是小白，可以看一下开发教程👉[如何参与开源项目？0基础入门：怎么打开GitHub？什么是issue？什么是PR？](https://www.bilibili.com/video/BV1EP411d7Np/?spm_id_from=333.999.0.0)

### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和该项目本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/popdf/issues)
- [gitee issue](https://gitee.com/CoderWanFeng/popdf/issues)
### 🧬贡献代码的步骤

1. 在Gitee或者Github上fork项目到自己的repo
2. 把fork过去的项目也就是你的项目clone到你的本地
3. 修改代码
4. commit后push到自己的库
5. 登录Gitee或Github在你首页可以看到一个 pull request 按钮，点击它，填写一些说明信息，然后提交到master分支即可。
6. 等待程序员晚枫合并，＋微信说一声更好👉[CoderWanFeng](http://python4office.cn/wechat-qrcode/)

-------------------------------------------------------------------------------

## 📌联系作者

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>

## 读者福利

几个没有套路的福利，每天都可以领一次~

<p align="center" id='福利合集-banner'>
    <a target="_blank" href='http://python4office.cn/sideline-pro-list/'>
    <img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/fuli.jpg" width="100%"/>
    </a>   
</p>